==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property crossResourceGroupMoveEnabled
 * @property crossSubscriptionMoveEnabled
 * @property validationRequired
 */
public data class ResourceTypeRegistrationPropertiesResourceMovePolicyArgs(
    public val crossResourceGroupMoveEnabled: Output<Boolean>? = null,
    public val crossSubscriptionMoveEnabled: Output<Boolean>? = null,
    public val validationRequired: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.builder()
            .crossResourceGroupMoveEnabled(crossResourceGroupMoveEnabled?.applyValue({ args0 -> args0 }))
            .crossSubscriptionMoveEnabled(crossSubscriptionMoveEnabled?.applyValue({ args0 -> args0 }))
            .validationRequired(validationRequired?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesResourceMovePolicyArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesResourceMovePolicyArgsBuilder internal constructor() {
    private var crossResourceGroupMoveEnabled: Output<Boolean>? = null

    private var crossSubscriptionMoveEnabled: Output<Boolean>? = null

    private var validationRequired: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("hrgpolxiscqboidq")
    public suspend fun crossResourceGroupMoveEnabled(`value`: Output<Boolean>) {
        this.crossResourceGroupMoveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("pioumiesexxnnyly")
    public suspend fun crossSubscriptionMoveEnabled(`value`: Output<Boolean>) {
        this.crossSubscriptionMoveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("cwvjcbnibuxxcypj")
    public suspend fun validationRequired(`value`: Output<Boolean>) {
        this.validationRequired = value
    }

    /**
     * @param value
     */
    @JvmName("nxwnjqkblkngepun")
    public suspend fun crossResourceGroupMoveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crossResourceGroupMoveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("wojedqsopbvpyvei")
    public suspend fun crossSubscriptionMoveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crossSubscriptionMoveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("daybyaftfexhwcxn")
    public suspend fun validationRequired(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validationRequired = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesResourceMovePolicyArgs =
        ResourceTypeRegistrationPropertiesResourceMovePolicyArgs(
            crossResourceGroupMoveEnabled = crossResourceGroupMoveEnabled,
            crossSubscriptionMoveEnabled = crossSubscriptionMoveEnabled,
            validationRequired = validationRequired,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property crossResourceGroupMoveEnabled
 * @property crossSubscriptionMoveEnabled
 * @property validationRequired
 */
public data class ResourceTypeRegistrationPropertiesResourceMovePolicyArgs(
    public val crossResourceGroupMoveEnabled: Output<Boolean>? = null,
    public val crossSubscriptionMoveEnabled: Output<Boolean>? = null,
    public val validationRequired: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesResourceMovePolicyArgs.builder()
            .crossResourceGroupMoveEnabled(crossResourceGroupMoveEnabled?.applyValue({ args0 -> args0 }))
            .crossSubscriptionMoveEnabled(crossSubscriptionMoveEnabled?.applyValue({ args0 -> args0 }))
            .validationRequired(validationRequired?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesResourceMovePolicyArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesResourceMovePolicyArgsBuilder internal constructor() {
    private var crossResourceGroupMoveEnabled: Output<Boolean>? = null

    private var crossSubscriptionMoveEnabled: Output<Boolean>? = null

    private var validationRequired: Output<Boolean>? = null

    /**
     * @param value
     */
    @JvmName("rjmcxktcmxrdcmwj")
    public suspend fun crossResourceGroupMoveEnabled(`value`: Output<Boolean>) {
        this.crossResourceGroupMoveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("mdevyxlrrrpcqaie")
    public suspend fun crossSubscriptionMoveEnabled(`value`: Output<Boolean>) {
        this.crossSubscriptionMoveEnabled = value
    }

    /**
     * @param value
     */
    @JvmName("qmhmdovhqjxkofqt")
    public suspend fun validationRequired(`value`: Output<Boolean>) {
        this.validationRequired = value
    }

    /**
     * @param value
     */
    @JvmName("ddpmfqxhelnrsnkm")
    public suspend fun crossResourceGroupMoveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crossResourceGroupMoveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("hrahexevwavmihio")
    public suspend fun crossSubscriptionMoveEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.crossSubscriptionMoveEnabled = mapped
    }

    /**
     * @param value
     */
    @JvmName("yfhfvpyluwkmxxac")
    public suspend fun validationRequired(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.validationRequired = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesResourceMovePolicyArgs =
        ResourceTypeRegistrationPropertiesResourceMovePolicyArgs(
            crossResourceGroupMoveEnabled = crossResourceGroupMoveEnabled,
            crossSubscriptionMoveEnabled = crossSubscriptionMoveEnabled,
            validationRequired = validationRequired,
        )
}
